==> tabular-data-gwt-service-2.2.0-20140625.151029-107.jar: org/gcube/portlets/user/td/gwtservice/shared/tr/column/MergeColumnSession.java <==
package org.gcube.portlets.user.td.gwtservice.shared.tr.column;

import java.io.Serializable;

import org.gcube.data.analysis.tabulardata.expression.Expression;
import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeCode;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class MergeColumnSession implements Serializable {

	private static final long serialVersionUID = -1896235499708614266L;

	protected ColumnData columnData;
	protected String label;
	protected Expression expression;
	protected ColumnTypeCode mergeColumnType;
	protected ColumnDataType mergeColumnDataType;

	public MergeColumnSession() {

	}

	/**
	 * 
	 * @param columnData
	 * @param label
	 * @param mergeColumnType
	 * @param mergeColumnDataType
	 * @param expression
	 */
	public MergeColumnSession(ColumnData columnData,
			String label, 
			ColumnTypeCode mergeColumnType,
			ColumnDataType mergeColumnDataType,
			Expression expression) {
		this.columnData = columnData;
		this.label = label;
		this.expression = expression;
		this.mergeColumnType=mergeColumnType;
		this.mergeColumnDataType=mergeColumnDataType;

	}

	public ColumnData getColumnData() {
		return columnData;
	}

	public void setColumnData(ColumnData columnData) {
		this.columnData = columnData;
	}

	public Expression getExpression() {
		return expression;
	}

	public void setExpression(Expression expression) {
		this.expression = expression;
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public ColumnTypeCode getMergeColumnType() {
		return mergeColumnType;
	}

	public void setMergeColumnType(ColumnTypeCode mergeColumnType) {
		this.mergeColumnType = mergeColumnType;
	}

	public ColumnDataType getMergeColumnDataType() {
		return mergeColumnDataType;
	}

	public void setMergeColumnDataType(ColumnDataType mergeColumnDataType) {
		this.mergeColumnDataType = mergeColumnDataType;
	}

	@Override
	public String toString() {
		return "MergeColumnSession [columnData=" + columnData + ", label="
				+ label + ", expression=" + expression + ", mergeColumnType="
				+ mergeColumnType + ", mergeColumnDataType="
				+ mergeColumnDataType + "]";
	}

	

	

}

==> tabular-data-gwt-service-2.5.1-20141210.173820-2.jar: org/gcube/portlets/user/td/gwtservice/shared/tr/column/MergeColumnSession.java <==
package org.gcube.portlets.user.td.gwtservice.shared.tr.column;

import java.io.Serializable;

import org.gcube.data.analysis.tabulardata.expression.Expression;
import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeCode;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class MergeColumnSession implements Serializable {

	private static final long serialVersionUID = -1896235499708614266L;

	protected ColumnData columnDataSource1;
	protected ColumnData columnDataSource2;
	protected String label;
	protected Expression expression;
	protected ColumnTypeCode mergeColumnType;
	protected ColumnDataType mergeColumnDataType;
	protected boolean deleteColumn;

	public MergeColumnSession() {

	}

	/**
	 * 
	 * @param columnData
	 * @param label
	 * @param mergeColumnType
	 * @param mergeColumnDataType
	 * @param expression
	 */
	public MergeColumnSession(ColumnData columnDataSource1,
			ColumnData columnDataSource2,
			String label, 
			ColumnTypeCode mergeColumnType,
			ColumnDataType mergeColumnDataType,
			Expression expression, boolean deleteColumn) {
		this.columnDataSource1 = columnDataSource1;
		this.columnDataSource2 = columnDataSource2;
		this.label = label;
		this.expression = expression;
		this.mergeColumnType=mergeColumnType;
		this.mergeColumnDataType=mergeColumnDataType;
		this.deleteColumn=deleteColumn;
	}


	public ColumnData getColumnDataSource1() {
		return columnDataSource1;
	}

	public void setColumnDataSource1(ColumnData columnDataSource1) {
		this.columnDataSource1 = columnDataSource1;
	}

	public ColumnData getColumnDataSource2() {
		return columnDataSource2;
	}

	public void setColumnDataSource2(ColumnData columnDataSource2) {
		this.columnDataSource2 = columnDataSource2;
	}

	public Expression getExpression() {
		return expression;
	}

	public void setExpression(Expression expression) {
		this.expression = expression;
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}

	public ColumnTypeCode getMergeColumnType() {
		return mergeColumnType;
	}

	public void setMergeColumnType(ColumnTypeCode mergeColumnType) {
		this.mergeColumnType = mergeColumnType;
	}

	public ColumnDataType getMergeColumnDataType() {
		return mergeColumnDataType;
	}

	public void setMergeColumnDataType(ColumnDataType mergeColumnDataType) {
		this.mergeColumnDataType = mergeColumnDataType;
	}
	
	public boolean isDeleteColumn() {
		return deleteColumn;
	}

	public void setDeleteColumn(boolean deleteColumn) {
		this.deleteColumn = deleteColumn;
	}

	@Override
	public String toString() {
		return "MergeColumnSession [columnDataSource1=" + columnDataSource1
				+ ", columnDataSource2=" + columnDataSource2 + ", label="
				+ label + ", expression=" + expression + ", mergeColumnType="
				+ mergeColumnType + ", mergeColumnDataType="
				+ mergeColumnDataType + ", deleteColumn=" + deleteColumn + "]";
	}

	
}
